"""
Author: RedFantom
License: GNU GPLv3
Copyright (c) 2017-2018 RedFantom
"""
from ttkthemes.themed_tk import ThemedTk
from ttkthemes.themed_style import ThemedStyle

THEMES = [
    "aquativo",
    "arc",
    "black",
    "blue",
    "clearlooks",
    "elegance",
    "equilux",
    "keramik",
    "kroc",
    "plastik",
    "radiance",
    "scidblue",
    "scidgreen",
    "scidgrey",
    "scidmint",
    "scidpink",
    "scidpurple",
    "scidsand",
    "ubuntu",
    "winxpblue",
]
